==> trip-0.1.0.tar.gz: trip-0.1.0/util/TcpServerSocket.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF ,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */





static const char* const TcpServerSocket_cxx_Version =
    "$Id: TcpServerSocket.cxx,v 1.12 2000/09/20 08:01:34 cvs Exp $";
#ifndef __vxworks


#include <errno.h>
#include <unistd.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <stdio.h>
#include <strings.h>


#include "VNetworkException.hxx"
#include "TcpServerSocket.hxx"
#include "VEnvVar.hxx"
#include "cpLog.h"

#define LISTENQ   5
TcpServerSocket::TcpServerSocket(int servPort) throw (VNetworkException&)
{
    _serverConn._connId = ::socket(AF_INET, SOCK_STREAM, 0);

    if (_serverConn._connId < 0)
    {
        // this is an error to do something
        char buf[256];
        sprintf(buf, "socket failed, reason: %s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    int on = 1;

#if defined (__linux__)
    if ( setsockopt ( _serverConn._connId, SOL_SOCKET, SO_REUSEADDR,
                      &on, sizeof ( on )) )
    {
        // this is an error -- can't set it
        char buf[256];
        sprintf(buf, "setsockopt failed, reason: %s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
#endif

    bzero(&_serverConn._connAddr, sizeof(_serverConn._connAddr));
    bzero(&_clientConn._connAddr, sizeof(_clientConn._connAddr));
    _serverConn._connAddr.sin_family = AF_INET;
    _serverConn._connAddr.sin_addr.s_addr = htonl(INADDR_ANY);
    _serverConn._connAddr.sin_port = htons(servPort);
    if (::bind(_serverConn._connId,
               (SA*)&_serverConn._connAddr,
               sizeof(_serverConn._connAddr))
       )
    {
        char buf[256];
        sprintf(buf, "Port %d, bind failed, reason:%s", servPort, strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
    if (::listen(_serverConn._connId, LISTENQ))
    {
        char buf[256];
        sprintf(buf, "listen failed, reason:%s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
}

TcpServerSocket::TcpServerSocket(const TcpServerSocket& other)
{
    _serverConn = other._serverConn;
    _clientConn = other._clientConn;
}

TcpServerSocket&
TcpServerSocket::operator=(TcpServerSocket& other)
{

    if (this != &other)
    {
        _serverConn = other._serverConn;
        _clientConn = other._clientConn;
    }
    return *this;
}

TcpServerSocket::TcpServerSocket() throw (VNetworkException&)
{
    _serverConn._connId = ::socket(AF_INET, SOCK_STREAM, 0);

    if (_serverConn._connId < 0)
    {
        // this is an error to do something
        char buf[256];
        sprintf(buf, "socket failed, reason: %s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

#if defined (__linux__)
    int on = 1;

    if ( setsockopt ( _serverConn._connId, SOL_SOCKET, SO_REUSEADDR,
                      &on, sizeof ( on )) )
    {
        // this is an error -- can't set it
        char buf[256];
        sprintf(buf, "setsockopt failed, reason: %s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
#endif

    bzero(&_serverConn._connAddr, sizeof(_serverConn._connAddr));
    bzero(&_clientConn._connAddr, sizeof(_clientConn._connAddr));
    _serverConn._connAddr.sin_family = AF_INET;
    _serverConn._connAddr.sin_addr.s_addr = htonl(INADDR_ANY);
    int port = VEnvVar::VPS_PORT;
    _serverConn._connAddr.sin_port = htons(port);

    if (::bind(_serverConn._connId,
               (SA*)&_serverConn._connAddr,
               sizeof(_serverConn._connAddr))
       )
    {
        char buf[256];
        sprintf(buf, "Port %d, bind failed, reason:%s", port, strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    if (::listen(_serverConn._connId, LISTENQ))
    {
        char buf[256];
        sprintf(buf, "listen failed, reason:%s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
}

TcpServerSocket::~TcpServerSocket()
{
    close();
}


int
TcpServerSocket::accept(Connection& con) throw (VNetworkException&)
{
    con._connAddrLen = sizeof(con._connAddr);
    if ((con._connId = ::accept(_serverConn._connId, (SA*) & con._connAddr, &con._connAddrLen)) < 0)
    {
        char buf[256];
        sprintf(buf, "Failed to except the connection, reason:%s", strerror(errno));
        cpLog(LOG_DEBUG, buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
    cpLog(LOG_DEBUG, "Connection from %s", con.getDescription().c_str());
    con._live = true;
    con.setState();
    return con._connId;
}

void
TcpServerSocket::close()
{
    ::close(_serverConn.getConnId());
}

#endif

==> trip-1.0.0.tar.gz: trip-1.0.0/util/TcpServerSocket.cxx <==

/* ====================================================================
 * The Vovida Software License, Version 1.0 
 * 
 * Copyright (c) 2000 Vovida Networks, Inc.  All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * 3. The names "VOCAL", "Vovida Open Communication Application Library",
 *    and "Vovida Open Communication Application Library (VOCAL)" must
 *    not be used to endorse or promote products derived from this
 *    software without prior written permission. For written
 *    permission, please contact vocal@vovida.org.
 *
 * 4. Products derived from this software may not be called "VOCAL", nor
 *    may "VOCAL" appear in their name, without prior written
 *    permission of Vovida Networks, Inc.
 * 
 * THIS SOFTWARE IS PROVIDED "AS IS" AND ANY EXPRESSED OR IMPLIED
 * WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND
 * NON-INFRINGEMENT ARE DISCLAIMED.  IN NO EVENT SHALL VOVIDA
 * NETWORKS, INC. OR ITS CONTRIBUTORS BE LIABLE FOR ANY DIRECT DAMAGES
 * IN EXCESS OF $1,000, NOR FOR ANY INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
 * PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR
 * PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY
 * OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE
 * USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH
 * DAMAGE.
 * 
 * ====================================================================
 * 
 * This software consists of voluntary contributions made by Vovida
 * Networks, Inc. and many individuals on behalf of Vovida Networks,
 * Inc.  For more information on Vovida Networks, Inc., please see
 * <http://www.vovida.org/>.
 *
 */





static const char* const TcpServerSocket_cxx_Version =
    "$Id: TcpServerSocket.cxx,v 1.15 2001/02/21 23:05:10 sprajpat Exp $";
#ifndef __vxworks


#include <errno.h>
#include <unistd.h>
#include <netinet/in.h>
#include <arpa/inet.h>
#include <stdio.h>
#include <strings.h>


#include "VNetworkException.hxx"
#include "TcpServerSocket.hxx"
#include "VEnvVar.hxx"
#include "cpLog.h"

#define LISTENQ   5
TcpServerSocket::TcpServerSocket(int servPort) throw (VNetworkException&)
{
    _serverConn._connId = ::socket(AF_INET, SOCK_STREAM, 0);

    if (_serverConn._connId < 0)
    {
        // this is an error to do something
        char buf[256];
        sprintf(buf, "socket failed, reason: %s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    int on = 1;

    if ( setsockopt ( _serverConn._connId, SOL_SOCKET, SO_REUSEADDR,
                      &on, sizeof ( on )) )
    {
        // this is an error -- can't set it
        char buf[256];
        sprintf(buf, "setsockopt failed, reason: %s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    bzero(&_serverConn._connAddr, sizeof(_serverConn._connAddr));
    bzero(&_clientConn._connAddr, sizeof(_clientConn._connAddr));
    _serverConn._connAddr.sin_family = AF_INET;
    _serverConn._connAddr.sin_addr.s_addr = htonl(INADDR_ANY);
    _serverConn._connAddr.sin_port = htons(servPort);
    if (::bind(_serverConn._connId,
               (SA*)&_serverConn._connAddr,
               sizeof(_serverConn._connAddr))
       )
    {
        char buf[256];
        sprintf(buf, "Port %d, bind failed, reason:%s", servPort, strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
    if (::listen(_serverConn._connId, LISTENQ))
    {
        char buf[256];
        sprintf(buf, "listen failed, reason:%s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
}

TcpServerSocket::TcpServerSocket(const TcpServerSocket& other)
{
    _serverConn = other._serverConn;
    _clientConn = other._clientConn;
}

TcpServerSocket&
TcpServerSocket::operator=(TcpServerSocket& other)
{

    if (this != &other)
    {
        _serverConn = other._serverConn;
        _clientConn = other._clientConn;
    }
    return *this;
}

TcpServerSocket::TcpServerSocket() throw (VNetworkException&)
{
    _serverConn._connId = ::socket(AF_INET, SOCK_STREAM, 0);

    if (_serverConn._connId < 0)
    {
        // this is an error to do something
        char buf[256];
        sprintf(buf, "socket failed, reason: %s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    int on = 1;

    if ( setsockopt ( _serverConn._connId, SOL_SOCKET, SO_REUSEADDR,
                      &on, sizeof ( on )) )
    {
        // this is an error -- can't set it
        char buf[256];
        sprintf(buf, "setsockopt failed, reason: %s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    bzero(&_serverConn._connAddr, sizeof(_serverConn._connAddr));
    bzero(&_clientConn._connAddr, sizeof(_clientConn._connAddr));
    _serverConn._connAddr.sin_family = AF_INET;
    _serverConn._connAddr.sin_addr.s_addr = htonl(INADDR_ANY);
    int port = VEnvVar::VPS_PORT;
    _serverConn._connAddr.sin_port = htons(port);

    if (::bind(_serverConn._connId,
               (SA*)&_serverConn._connAddr,
               sizeof(_serverConn._connAddr))
       )
    {
        char buf[256];
        sprintf(buf, "Port %d, bind failed, reason:%s", port, strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }

    if (::listen(_serverConn._connId, LISTENQ))
    {
        char buf[256];
        sprintf(buf, "listen failed, reason:%s", strerror(errno));
        cpLog(LOG_ALERT, "%s", buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
}

TcpServerSocket::~TcpServerSocket()
{
    close();
}


int
TcpServerSocket::accept(Connection& con) throw (VNetworkException&)
{
    con._connAddrLen = sizeof(con._connAddr);
    if ((con._connId = ::accept(_serverConn._connId, (SA*) & con._connAddr, &con._connAddrLen)) < 0)
    {
        char buf[256];
        sprintf(buf, "Failed to accept the connection, reason:%s", strerror(errno));
        cpLog(LOG_DEBUG, buf);
        throw VNetworkException(buf, __FILE__, __LINE__, errno);
    }
    cpLog(LOG_DEBUG, "Connection from %s", con.getDescription().c_str());
    con._live = true;
    con.setState();
    return con._connId;
}

void
TcpServerSocket::close()
{
    ::close(_serverConn.getConnId());
}

#endif
